@@ -1,9 +1,27 @@
-import ast
+# 
+# Copyright (C) 2012  Matthew J Desmarais
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
 import copy
 import inspect
 import logging
 import sys
 
+from astkit import ast
+
 log = logging.getLogger(__name__)
 
 DEFAULT_INDENTATION = 4
@@ -260,8 +278,12 @@ class SourceCodeRenderer(ast.NodeVisitor):
             self.end_block()
     
     def render_FunctionDef(self, node):
+        if sys.version_info[:2] < (2, 6):
+            decorators = node.decorators
+        else:
+            decorators = node.decorator_list
         source = "\n".join(['@' + self._render(dec)
-                         for dec in node.decorator_list])
+                         for dec in decorators])
         if source:
             source += "\n"
         source += "def %s(" % node.name
